OC.L10N.register(
    "settings",
    {
    "Unable to change password" : "암호를 변경할 수 없음",
    "Very weak password" : "매우 약한 암호",
    "Weak password" : "약한 암호",
    "So-so password" : "그저 그런 암호",
    "Good password" : "좋은 암호",
    "Strong password" : "강력한 암호",
    "{actor} added you to group {group}" : "{actor} 가 당신을 {group} 그룹에 추가했습니다.",
    "You added {user} to group {group}" : "당신은 {user}를 {group} 그룹에 추가했습니다.",
    "{actor} added {user} to group {group}" : "{actor} 가 {user}를 {group} 그룹에 추가했습니다.",
    "An administrator added you to group {group}" : "관리자가 당신을 {group} 그룹에 추가했습니다.",
    "An administrator added {user} to group {group}" : "관리자가 {user}를 {group} 그룹에 추가했습니다.",
    "{actor} removed you from group {group}" : "{actor}가 당신을 {group} 그룹에서 삭제했습니다.",
    "You removed {user} from group {group}" : "당신이 {user}를 {group} 그룹에서 삭제했습니다.",
    "{actor} removed {user} from group {group}" : "{actor}가 {user}를 {group} 그룹에서 삭제했습니다.",
    "An administrator removed you from group {group}" : "관리자가 당신을 {group} 그룹에서 삭제했습니다.",
    "An administrator removed {user} from group {group}" : "관리자가 {user}를 {group} 그룹에서 삭제했습니다.",
    "Your <strong>group memberships</strong> were modified" : "당신의 <strong>그룹 멤버십</strong>이 수정되었습니다.",
    "{actor} changed your password" : "{actor} 님이 내 암호를 변경함",
    "You changed your password" : "내 암호를 변경함",
    "Your password was reset by an administrator" : "관리자가 내 암호를 초기화함",
    "Your password was reset" : "암호가 재설정 되었습니다.",
    "{actor} changed your email address" : "{actor} 님이 내 이메일 주소를 변경함",
    "You changed your email address" : "내 이메일 주소를 변경함",
    "Your email address was changed by an administrator" : "관리자가 내 이메일 주소를 변경함",
    "You created an app password for a session named \"{token}\"" : "세션 \"{token}\"에 대한 앱 압호를 생성했습니다",
    "An administrator created an app password for a session named \"{token}\"" : "관리자가 세션 \"{token}\"에 대한 앱 압호를 생성했습니다",
    "You deleted app password \"{token}\"" : "앱 패스워드 \"{token}\"이 제거되었습니다.",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "앱 패스워드 \"{token}\"의 이름을 \"{newToken}\"으로 바꿨습니다.",
    "You granted filesystem access to app password \"{token}\"" : "앱 패스워드 \"{token}\"에 대해 파일 시스템 접근을 허가함",
    "You revoked filesystem access from app password \"{token}\"" : "앱 패스워드 \"{token}\"에 대해 파일 시스템 접근 권한을 철회함",
    "Security" : "보안",
    "You successfully logged in using two-factor authentication (%1$s)" : "2단계 인증으로 로그인함(%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "2단계 인증 시도가 실패함(%1$s)",
    "Remote wipe was started on %1$s" : "원격 제거가 %1$s에 시작됨",
    "Remote wipe has finished on %1$s" : "원격 제거가 %1$s에 완료됨",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "내 <strong>암호</strong> 및 <strong>이메일</strong>이 변경됨",
    "Settings" : "설정",
    "Could not remove app." : "앱을 삭제할 수 없음",
    "Could not update app." : "앱을 업데이트 할 수 없음",
    "Wrong password" : "잘못된 암호",
    "Unable to change personal password" : "개인 패스워드를 변경할 수 없음",
    "Saved" : "저장됨",
    "No Login supplied" : "로그인 정보 없음",
    "Unable to change password. Password too long." : "패스워드를 변경할 수 없음. 패스워드가 너무 긺.",
    "Authentication error" : "인증 오류",
    "Please provide an admin recovery password; otherwise, all account data will be lost." : "관리자 복구 암호를 입력하십시오. 그렇지 않으면 모든 계정 데이터가 초기화됩니다.",
    "Wrong admin recovery password. Please check the password and try again." : "관리자 복구 암호가 잘못되었습니다. 암호를 다시 확인하십시오.",
    "Backend does not support password change, but the encryption of the account key was updated." : "백엔드에서 암호 변경을 지원하지 않지만, 계정 키의 암호화가 갱신되었습니다.",
    "Administrator documentation" : "관리자 문서",
    "User documentation" : "사용자 문서",
    "Nextcloud help overview" : "Nextcloud 도움말 개관",
    "Invalid SMTP password." : "SMTP 암호가 잘못되었습니다.",
    "Email setting test" : "이메일 설정 시험",
    "Well done, %s!" : "%s 님, 잘 하셨습니다!",
    "If you received this email, the email configuration seems to be correct." : "이 이메일을 받으셨다면 이메일 설정이 올바릅니다.",
    "Email could not be sent. Check your mail server log" : "이메일을 보낼 수 없습니다. 메일 서버 로그를 확인하십시오.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "이메일을 보내는 중 오류가 발생했습니다. 설정을 확인하십시오.(오류: %s)",
    "You need to set your account email before being able to send test emails. Go to %s for that." : "이메일 발송 테스트를 진행하기 앞서 계정 이메일을 설정해야 합니다. 설정을 위해 %s(으)로 가십시오.",
    "Recently active" : "최근 활동함",
    "Disabled accounts" : "비활성화된 계정",
    "Invalid account" : "잘못된 계정",
    "Invalid mail address" : "잘못된 이메일 주소",
    "Settings saved" : "설정 저장됨",
    "Unable to change full name" : "전체 이름을 변경할 수 없음",
    "Unable to change email address" : "이메일 주소를 변경할 수 없음",
    "Unable to set invalid phone number" : "올바르지 않은 전화번호를 설정할 수 없음",
    "Unable to set invalid website" : "올바르지 않은 웹사이트 주소를 설정할 수 없음",
    "Some account data was invalid" : "몇 가지 계정 데이터가 올바르지 않음",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "내 트위터 계정을 확인하려면 다음 트윗을 타임라인에 게시하십시오(줄바꿈을 추가하지 마십시오):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "내 웹 사이트를 확인하려면 다음 내용을 웹 사이트 루트 디렉터리의 '.well-known/CloudIdVerificationCode.txt' 파일에 게시하십시오(전체 텍스트가 한 줄에 들어가야 함):",
    "%1$s changed your password on %2$s." : "%1$s 님이 내 암호를 %2$s에 변경했습니다.",
    "Your password on %s was changed." : "내 %s 암호를 변경했습니다.",
    "Your password on %s was reset by an administrator." : "관리자가 내 %s 암호를 초기화했습니다.",
    "Your password on %s was reset." : "내 %s 암호를 변경했습니다.",
    "Password for %1$s changed on %2$s" : "%1$s의 암호를 %2$s에 변경함",
    "Password changed for %s" : "%s의 암호 변경됨",
    "If you did not request this, please contact an administrator." : "요청하지 않았다면 관리자에게 연락하십시오.",
    "Your email address on %s was changed." : "내 %s 이메일 주소를 변경했습니다.",
    "Your email address on %s was changed by an administrator." : "관리자가 내 %s 이메일 주소를 변경했습니다.",
    "Email address for %1$s changed on %2$s" : "%1$s의 이메일 주소를 %2$s에 변경함",
    "Email address changed for %s" : "%s의 이메일 주소 변경됨",
    "The new email address is %s" : "새 이메일 주소는 %s입니다",
    "Your %s account was created" : "%s 계정을 등록했습니다",
    "Welcome aboard" : "환영합니다",
    "Welcome aboard %s" : "%s 님, 환영합니다",
    "Welcome to your %s account, you can add, protect, and share your data." : "%s 계정에 오신 것을 환영합니다. 데이터를 추가, 보호, 공유할 수 있습니다.",
    "Your Login is: %s" : "로그인된 계정: %s",
    "Set your password" : "내 암호 설정하기",
    "Go to %s" : "%s(으)로 이동",
    "Install Client" : "클라이언트 설치",
    "Logged in account must be a sub admin" : "로그인한 계정은 부관리자여야 합니다.",
    "Apps" : "앱",
    "Personal" : "개인",
    "Administration" : "관리",
    "Users" : "사용자",
    "Additional settings" : "고급 설정",
    "Assistant" : "어시스턴트",
    "Administration privileges" : "관리 권한",
    "Groupware" : "그룹웨어",
    "Overview" : "개요",
    "Quick presets" : "빠른 사전 설정",
    "Basic settings" : "기본 설정",
    "Sharing" : "공유",
    "Availability" : "시간 조율",
    "Calendar" : "달력",
    "Personal info" : "개인 정보",
    "Mobile & desktop" : "모바일 & 데스크톱",
    "Artificial Intelligence" : "인공지능",
    "Email server" : "이메일 서버",
    "Mail Providers" : "메일 제공자",
    "Mail provider enables sending emails directly through the user's personal email account. At present, this functionality is limited to calendar invitations. It requires Nextcloud Mail 4.1 and an email account in Nextcloud Mail that matches the user's email address in Nextcloud." : "메일 제공자는 사용자의 개인 이메일 계정을 통해 이메일을 직접 보낼 수 있도록 합니다. 현재 이 기능은 달력 초대에만 가능합니다. Nextcloud 메일 4.1이 필요하며, Nextcloud에 등록된 사용자의 이메일 주소와 일치하는 이메일 계정이 Nextcloud 메일에 있어야 합니다.",
    "Send emails using" : "다음을 사용하여 이메일 보내기",
    "User's email account" : "사용자 이메일 계정",
    "System email account" : "시스템 이메일 계정",
    "Security & setup checks" : "보안 & 설정 검사",
    "Settings presets" : "사전 설정된 설정",
    "Background jobs" : "배경 작업",
    "Unlimited" : "무제한",
    "Verifying" : "검사",
    "Verifying …" : "확인 중 …",
    "Verify" : "확인",
    "Allowed admin IP ranges" : "허용된 관리자 IP 범위",
    "Admin IP filtering isn't applied." : "관리자 IP 필터링이 적용되지 않습니다.",
    "Configuration key \"%1$s\" expects an array (%2$s found). Admin IP range validation will not be applied." : "\"%1$s\" 설정 키에는 배열(%2$s 발견)이  필요합니다. 관리자 IP 범위 검사가 적용되지 않습니다.",
    "Configuration key \"%1$s\" contains invalid IP range(s): \"%2$s\"" : "\"%1$s\" 설정 키에 잘못된 IP 범위(들이)가 있습니다: \"%2$s\"",
    "Admin IP filtering is correctly configured." : "관리자 IP 필터링이 올바르게 설정되었습니다.",
    "App directories owner" : "앱 디렉토리 소유자",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:\n%s" : "일부 앱 디렉토리를 웹 서버가 아닌 다른 사용자가 소유하고 있습니다. 앱을 수동으로 설치한 경우에 발생할 수 있습니다. 다음 앱 디렉토리의 사용 권한을 확인하십시오: %s",
    "App directories have the correct owner \"%s\"" : "앱 디렉토리가 소유자 \"%s\"이(가) 올바릅니다",
    "Brute-force Throttle" : "무차별 대입 공격 쓰로틀링",
    "Your remote address could not be determined." : "원격 주소가 지정되지 않았습니다",
    "Your remote address was identified as \"%s\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly." : "당신의 원격지 주소는 \"%s\"(으)로 식별되며, 현재 무차별 대입 공격 방어를 위해 여러 요청의 성능을 저하시켰습니다. 위 원격지 주소가 당신의 주소가 아니라면, 프록시 설정이 제대로 되지 않았음을 나타냅니다.",
    "Your remote address \"%s\" is not brute-force throttled." : "원격지 주소 \"%s\"은(는) 무차별 대입 공격 쓰로틀링이 작동되지 않았습니다.",
    "Old administration imported certificates" : "과거 관리자가 인증서를 가져왔습니다",
    "A background job is pending that checks for administration imported SSL certificates. Please check back later." : "관리자가 불러온 SSL 인증서를 확인하는 백그라운드 작업이 진행중입니다. 나중에 다시 확인하십시오.",
    "There are some administration imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "현재 관리자가 불러온 SSL 인증서 중 Nextcloud 21과 함께 사용할 수 없는 것이 있습니다. 이러한 인증서는 커맨드라인 명령어 \"occ security:certificates:import\"로 불러올 수 있습니다. 데이터 디렉토리 내부에 있는 해당 인증서의 경로가 아래에 표시됩니다.",
    "Code integrity" : "코드 무결성",
    "Integrity checker has been disabled. Integrity cannot be verified." : "무결성 검사가 비활성화 되었습니다. 무결성을 검증할 수 없습니다.",
    "No altered files" : "대체된 파일 없음",
    "Some files have not passed the integrity check. {link1} {link2}" : "일부 파일이 무결성 검사를 통과하지 못했습니다. {link1} {link2}",
    "List of invalid files…" : "잘못된 파일들의 목록…",
    "Rescan…" : "다시 스캔…",
    "Cron errors" : "Cron 오류",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:\n%s" : "CLI를 통한 Cron 작업을 수행할 수 없습니다. 다음의 오류가 발생하였습니다: %s",
    "The last cron job ran without errors." : "마지막 Cron 작업이 정상적으로 수행되었습니다.",
    "Cron last run" : "마지막 Cron 작업",
    "Last background job execution ran %s. Something seems wrong. {link}." : "마지막 작업이 %s에 실행된 것 같습니다. 문제를 확인하십시오. {link}",
    "Last background job execution ran %s." : "마지막 백그라운드 작업이 %s에 수행되었습니다. ",
    "Data directory protected" : "데이터 경로가 보호됨",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "현재 인터넷을 통해 누구나 당신의 데이터 디렉토리에 직접 접근할 수도 있습니다. .hraccess 파일이 동작하지 않고 있습니다. 웹 서버를 설정하여 데이터 디렉토리에 직접 접근할 수 없도록 하거나, 웹 서버 루트 밖으로 데이터 디렉토리를 이전하십시오.",
    "Could not check that the data directory is protected. Please check manually that your server does not allow access to the data directory." : "데이터 경로의 보호 여부를 확인할 수 없습니다. 이 서버가 데이터 경로 접근을 금지하는지 수동으로 확인하십시오.",
    "Database missing columns" : "데이터베이스의 행이 사라졌습니다",
    "Missing optional column \"%s\" in table \"%s\"." : "표 \"%s\"의 optional column \"%s\"이(가) 사라졌습니다",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "데이터베이스에 일부 선택적 열이 누락되었습니다. 큰 테이블에 열을 추가하는 데 시간이 걸릴 수 있기 때문에 선택 사항일 수 있는 열이 자동으로 추가되지 않았습니다. 명령행에서 \"occ db:add-missing-columns\"를 실행하면 누락된 열을 인스턴스를 실행되는 동안 수동으로 추가할 수 있습니다. 열이 추가되면 일부 기능의 응답성이나 사용성이 향상될 수 있습니다.",
    "Database missing indices" : "데이터베이스의 색인이 사라졌습니다",
    "Missing indices:" : "빠진 인덱스:",
    "Detected some missing optional indices. Occasionally new indices are added (by Nextcloud or installed applications) to improve database performance. Adding indices can sometimes take awhile and temporarily hurt performance so this is not done automatically during upgrades. Once the indices are added, queries to those tables should be faster. Use the command `occ db:add-missing-indices` to add them." : "일부 선택적 인덱스가 빠진 것을 감지했습니다. 데이터베이스 성능을 향상하기 위해 때때로 (Nextcloud나 설치된 앱을 통해) 새로운 인덱스가 추가됩니다. 인덱스 추가는 가끔 시간이 걸려 일시적으로 성능을 저하시킬 수 있기 때문에 자동으로 업데이트 중에 실행되지 않습니다. 인덱스가 추가되면 그 테이블에 질의하는 것이 빨라집니다. `occ db:add-missing-indices` 명령을 사용해 추가하세요.",
    "Database missing primary keys" : "데이터베이스의 기본 키가 사라졌습니다",
    "Missing primary key on table \"%s\"." : "표 \"%s\"의 기본키가 사라졌습니다",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "데이터베이스에 일부 기본 키가 누락되었습니다. 큰 테이블에 기본 키를 추가하는 데 시간이 걸릴 수 있기 때문에 자동으로 추가되지 않았습니다. 명령행에서 \"occ db:add-missing-primary-keys\"를 실행하면 인스턴스가 계속 실행되는 동안 누락된 기본 키를 수동으로 추가할 수 있습니다.",
    "Database pending bigint migrations" : "bigint 마이그레이션 보류중인 데이터베이스",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline." : "일부 데이터베이스 열이 big int로 변환되지 않았습니다. 큰 테이블의 열 형식을 변환하는 데 시간이 걸리기 때문에 자동으로 변환하지 않았습니다. 명령행에서 \"occ db:convert-filecache-bigint\" 명령을 실행하여 변경 사항을 직접 적용할 수 있습니다. 이 작업은 인스턴스를 오프라인으로 전환하고 실행해야 합니다. 더 많은 정보를 보려면 이에 관한 문서 페이지 ↗ 를 참조하십시오.",
    "Debug mode" : "디버그 모드",
    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "이 인스턴스는 디버그 모드에서 작동 중입니다. 프로덕션 환경이 아닌 로컬 개발을 위해서만 활성화 하세요.",
    "Debug mode is disabled." : "디버그 모드가 비활성화 되었습니다.",
    "Default phone region" : "기본 국가 번호",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the region to your config file." : "기본 국가 번호가 설정되지 않았습니다. 기본 국가 번호를 설정하면 프로필에서 국가 번호를 생략하고 전화번호를 입력할 수 있습니다. ISO 3166-1 코드를 참조하여 설정 파일에 \"default_phone_region\"을 추가하십시오.",
    "Email test" : "이메일 시험",
    "Mail delivery is disabled by instance config \"%s\"." : "인스턴스의 \"%s\" 설정에 의해 메일 전달이 비활성화 되었습니다.",
    "Email test was successfully sent" : "시험 이메일이 성공적으로 전송됨",
    "You have not set or verified your email server configuration, yet. Please head over to the \"Basic settings\" in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "이메일 서버 설정이 입력되지 않았거나 검증되지 않았습니다. \"기본 설정\"으로 이동해 설정을 완료하십시오. 서버 정보를 입력한 후 양식 아래 \"이메일 발송\" 버튼을 눌러 설정을 검증하십시오.",
    "Transactional File Locking" : "트랜잭션 파일 잠금",
    "Transactional File Locking is disabled. This is not a a supported configuraton. It may lead to difficult to isolate problems including file corruption. Please remove the `'filelocking.enabled' => false` configuration entry from your `config.php` to avoid these problems." : "트랜잭션 파일 잠금이 비활성화 되었습니다. 이 설정은 지원되지 않습니다. 때문에 파일 손상 등의 문제를 차단하는 데 어려움이 생길 수 있습니다. 이 문제를 방지하려면 `config.php`에서 `'filelocking.enabled' => false` 설정 항목을 제거하세요.",
    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available." : "데이터베이스가 트랜잭션 파일 잠금에 사용됩니다. 성능을 향상하려면, 가능한 경우 memcache를 설정하십시오.",
    "Forwarded for headers" : "헤더에 전달됨",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array." : "\"trusted_proxies\" 설정이 바르지 않습니다. 배열(array) 형식으로 설정해야 합니다.",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array of IP addresses - optionally with range in CIDR notation." : "\"trusted_proxies\" 설정이 올바르지 않습니다. IP 주소의 열(arrary)로 지정되어야 합니다. CIDR 표기법을 통해 IP주소의 범위 형태로도 설정할 수 있습니다.",
    "The reverse proxy header configuration is incorrect. This is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "역방향 프록시 헤더 설정이 잘못되었습니다. 이는 보안과 관련된 문제이며, 공격자가 Nextcloud 상에서 IP 주소를 스푸핑할 수 있습니다.",
    "Your IP address was resolved as %s" : "IP 주소가 %s(으)로 resolve 됨",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "역방향 프록시 헤더 설정이 올바르지 않거나 신뢰하는 프록시를 통해 Nextcloud에 접근하고 있을 수 있습니다. 그렇지 않다면, 이는 보안 문제이며 공격자가 Nextcloud 상에서 IP 주소를 스푸핑할 수 있습니다. ",
    "HTTPS access and URLs" : "HTTPS 접근 및 URL",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "HTTP를 통해 사이트에 안전하지 않게 액세스하고 있습니다. HTTPS를 필수적으로 사용하도록 서버를 설정할 것을 강력히 권장합니다. 그렇지 않으면 \"클립보드에 복사\" 또는 \"서비스 워커\"와 같은 중요한 웹 기능이 작동하지 않습니다!",
    "Accessing site insecurely via HTTP." : "HTTP를 통해 안전하지 않게 사이트에 접근합니다.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly." : "당신의 인스턴스에 안전하게 연결되어 액세스하고 있지만,  인스턴스가 안전하지 않은 URL을 생성합니다. 이는 당신의 인스턴스가 역방향 프록시 뒤에 있고 Nextcloud `overwrite*` 설정이 올바르게 되지 않았기 때문일 수 있습니다.",
    "Your instance is generating insecure URLs. If you access your instance over HTTPS, this likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly." : "당신의 인스턴스가 안전하지 않은 URL를 생성합니다. HTTPS를 통해 액세스했다면, 이는 당신의 인스턴스가 역방향 프록시 뒤에 있고 Nextcloud `overwrite*` 설정이 올바르게 되지 않았기 때문일 수 있습니다.",
    "You are accessing your instance over a secure connection, and your instance is generating secure URLs." : "당신의 인스턴스에 안전하게 연결되어 액세스하고 있고, 인스턴스가 안전한 URL을 생성합니다.",
    "Internet connectivity" : "인터넷 연결",
    "Internet connectivity is disabled in configuration file." : "인터넷 연결이 설정 파일에서 비활성화 되었습니다",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "서버가 인터넷에 연결되지 않아 다수의 종단점에 도달할 수 없습니다. 이로 인해 외부 저장소 마운트, 서드파티 앱 업데이트와 설치에 대한 알림 수신 등의 기능을 사용할 수 없을 것입니다. 원격 파일 접근과 알림 이메일 전송 또한 작동하지 않을 것입니다. 서버를 인터넷과 연결하여 모든 기능을 사용하십시오.",
    "JavaScript modules support" : "JavaScript 모듈 지원",
    "Unable to run check for JavaScript support. Please remedy or confirm manually if your webserver serves `.mjs` files using the JavaScript MIME type." : "JavaScript 지원 여부를 확인할 수 없습니다. 이 웹 서버가 JavaScript MIME 타입을 통해 `.mjs` 파일을 제공하는지를 수동으로 확인하거나 해결하십시오.",
    "Your webserver does not serve `.mjs` files using the JavaScript MIME type. This will break some apps by preventing browsers from executing the JavaScript files. You should configure your webserver to serve `.mjs` files with either the `text/javascript` or `application/javascript` MIME type." : "이 웹 서버는 JavaScript MIME 타입을 활용해 `.mjs` 파일을 제공하지 않습니다. 브라우저에서 JavaScript 파일을 실행할 수 없으므로, 일부 앱이 정상적으로 작동하지 않을 것입니다. 웹 서버가 `text/javascript` 및 `application/javascript` MIME 타입을 활용하여 `.mjs` 파일을 제공하도록 설정하십시오.",
    "JavaScript source map support" : "JavaScript 소스 맵 지원",
    "Your webserver is not set up to serve `.js.map` files. Without these files, JavaScript Source Maps won't function properly, making it more challenging to troubleshoot and debug any issues that may arise." : "당신의 웹서버가 `.js.map` 파일을 제공하도록 설정되지 않았습니다. 이 파일들 없이는 JavaScript Source Maps가 올바르게 작동하지 않으며, 발생할 문제들을 해결하고 디버깅하기 더 어려워집니다.",
    "Old server-side-encryption" : "구식 서버 측 암호화",
    "Disabled" : "비활성화됨",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "구형 포맷의 서버 측 암호화가 활성화된 상태입니다. 이를 비활성화 하는 것을 권장합니다.",
    "Logging level" : "로그 단계",
    "The %1$s configuration option must be a valid integer value." : "%1$s설정 옵션은 유효한 정수 값이어야만 합니다.",
    "The logging level is set to debug level. Use debug level only when you have a problem to diagnose, and then reset your log level to a less-verbose level as it outputs a lot of information, and can affect your server performance." : "로그 단계가 디버그 단계로 설정되어 있습니다. 디버그 단계는 문제를 진단할 때만 사용하고, 문제가 해결되면 로그 단계를 더 간략한 단계로 되돌리십시오. 디버그 단계는 많은 정보를 출력하여 서버 성능에 영향을 줄 수 있습니다.",
    "Logging level configured correctly." : "로그 단계가 올바르게 설정되었습니다.",
    "Maintenance window start" : "유지 보수 창 시작",
    "Server has no maintenance window start time configured. This means resource intensive daily background jobs will also be executed during your main usage time. We recommend to set it to a time of low usage, so users are less impacted by the load caused from these heavy tasks." : "서버 유지관리 창의 시작 시간이 설정되지 않았습니다. 많은 사용자가 접속하는 시간대에 자원 집약적인 작업이 실행될 수 있습니다. 부하가 큰 작업에 의해 사용자가 불편을 겪지 않도록, 유지관리 창의 시작 시간을 사용량이 적은 시간대로 설정하십시오.",
    "Maintenance window to execute heavy background jobs is between {start}:00 UTC and {end}:00 UTC" : "유지 보수 창이 부하가 큰 백그라운드 작업을 수행하기 위해 {start}:00 UTC에서 {end}:00 UTC에 동작합니다",
    "Memcache" : "Memcache",
    "Memcached is configured as distributed cache, but the wrong PHP module (\"memcache\") is installed. Please install the PHP module \"memcached\"." : "Memcached가 분산 캐시로 구성되어 있지만 잘못된 PHP 모듈 (\"memcache\")가 설치되어 있습니다. PHP 모듈 \"memcached\"를 설치하세요.",
    "Memcached is configured as distributed cache, but the PHP module \"memcached\" is not installed. Please install the PHP module \"memcached\"." : "Memcached가 분산 캐시로 구성되어 있지만 PHP 모듈 \"memcached\"가 설치되어 있지 않습니다. PHP 모듈 \"memcached\"를 설치하세요.",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available." : "메모리 캐시가 설정되지 않았습니다. 성능 향상을 위해, 가능한 경우 memcache를 설정하십시오.",
    "Failed to write and read a value from local cache." : "로컬 캐시에 값을 쓰거나 읽을 수 없습니다.",
    "Failed to write and read a value from distributed cache." : "분산 캐시에 값을 쓰거나 읽을 수 없습니다.",
    "Configured" : "설정됨",
    "Mimetype migrations available" : "Mimetype 마이그레이션 가능",
    "One or more mimetype migrations are available. Occasionally new mimetypes are added to better handle certain file types. Migrating the mimetypes take a long time on larger instances so this is not done automatically during upgrades. Use the command `occ maintenance:repair --include-expensive` to perform the migrations." : "하나 이상의 MIME 유형 마이그레이션이 가능합니다. 특정 파일 형식을 더 잘 처리하기 위해 새로운 MIME 유형이 추가되는 경우가 있습니다. 대규모 인스턴스에서는 MIME 유형 마이그레이션에 시간이 오래 걸리므로 업그레이드 시 자동으로 수행되지 않습니다. 마이그레이션을 수행하려면 `occ maintenance:repair --include-expensive` 명령을 사용하십시오.",
    "MySQL row format" : "MySQL 행 형식",
    "You are not using MySQL" : "MySQL을 사용하고 있지 않습니다",
    "None of your tables use ROW_FORMAT=Compressed" : "ROW_FORMAT=Compressed인 테이블이 없습니다.",
    "Incorrect row format found in your database. ROW_FORMAT=Dynamic offers the best database performances for Nextcloud. Please update row format on the following list: %s." : "데이터베이스에서 잘못된 행 형식이 발견되었습니다. ROW_FORMAT=Dynamic은 Nextcloud에서 최상의 데이터베이스 성능을 제공합니다. 다음 목록에서 행 형식을 업데이트하십시오: %s",
    "MySQL Unicode support" : "MySQL 유니코드 지원",
    "MySQL is used as database and does support 4-byte characters" : "MySQL이 데이터베이스로 사용되고 있으며 4바이트 문자를 지원합니다",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL." : "MySQL이 데이터베이스로 사용되고 있으나 4바이트 문자를 지원하지 않고 있습니다. 파일 이름이나 댓글 등에 Emoji와 같은 4바이트 문자를 문제 없이 사용하기 위해, MySQL에서 4바이트 문자 지원을 활성화하길 권장합니다.",
    "OCS provider resolving" : "OCS 제공자 해석",
    "Could not check if your web server properly resolves the OCM and OCS provider URLs." : "웹 서버가 OCM 및 OCS 공급자 URL을 제대로 해석하는지 확인할 수 없습니다.",
    "Your web server is not properly set up to resolve %1$s.\nThis is most likely related to a web server configuration that was not updated to deliver this folder directly.\nPlease compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx.\nOn Nginx those are typically the lines starting with \"location ~\" that need an update." : "웹 서버가 %1$s를 제대로 해석하도록 설정되어 있지 않습니다. \n이 문제는 웹 서버 구성이 해당 폴더를 직접 제공하도록 업데이트되지 않았기 때문일 가능성이 높습니다. \nApache의 경우 \".htaccess\" 파일에 있는 기본 rewrite 규칙과, Nginx의 경우 설명서에 제공된 rewrite 규칙과 현재 구성을 비교해 보세요.\nNginx의 경우 일반적으로 \"location ~\"로 시작하는 줄을 업데이트해야 합니다.",
    "Overwrite CLI URL" : "CLI URL 덮어쓰기",
    "The \"overwrite.cli.url\" option in your config.php is correctly set to \"%s\"." : "\"overwrite.cli.url\" 옵션이 config.php에서 \"%s\"(으)로 바르게 설정되어 있습니다.",
    "The \"overwrite.cli.url\" option in your config.php is set to \"%s\" which is a correct URL. Suggested URL is \"%s\"." : "\"overwrite.cli.url\" 옵션이 config.php에서 \"%s\"(으)로 바르게 설정되어 있습니다. 권장 URL은 \"%s\" 입니다.",
    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"%s\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "주로 사용할 URL이 config.php 파일의 \"overwrite.cli.url\" 옵션에 올바르게 설정되어 있는지 확인하십시오. 제안: \"%s\". 설정이 잘못되었을 경우 cron을 통한 URL 생성에 문제가 생길 수 있습니다. (제안된 URL이 이 Nextcloud에 접근하는 주된 URL이 아닐 수 있습니다. 따라서, 해당 사항을 직접 재확인하는 것이 좋습니다.)",
    "PHP APCu configuration" : "PHP APCu 설정",
    "Your APCu cache has been running full, consider increasing the apc.shm_size php setting." : "APCu 캐시가 가득 찼으므로, php 설정에서 apc.shm_size를 늘리는 것을 고려해 보세요.",
    "Your APCu cache is almost full at %s%%, consider increasing the apc.shm_size php setting." : "APCu 캐시가 %s%%정도로 거의 가득 찼으므로, php 설정에서 apc.shm_size를 늘리는 것을 고려해 보세요.",
    "PHP default charset" : "PHP 기본 문자셋",
    "PHP configuration option \"default_charset\" should be UTF-8" : "PHP 설정 \"default_charset\"이 UTF-8이어야 합니다",
    "PHP set_time_limit" : "PHP set_time_limit",
    "The function is available." : "기능을 사용할 수 있습니다.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP 함수 \"set_time_limit\"을 사용할 수 없습니다. 스크립트가 실행 중간에 중지되어 설치를 깨트릴 수도 있습니다. 이 함수를 활성화하는 것을 추천합니다.",
    "Freetype" : "FreeType",
    "Supported" : "지원됨",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "PHP에 Freetype 지원이 없습니다. 프로필 사진과 설정 인터페이스가 올바르게 표시되지 않을 수도 있습니다.",
    "PHP getenv" : "PHP getenv",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP에서 시스템 환경 변수를 올바르게 조회할 수 없는 것 같습니다. getenv(\"PATH\") 시험 결과 빈 값이 반환되었습니다.",
    "PHP file size upload limit" : "PHP 파일 크기 업로드 제한",
    "The PHP upload_max_filesize is too low. A size of at least %1$s is recommended. Current value: %2$s." : "PHP의 upload_max_filesize가 너무 작습니다. 최소한 %1$s 이상의 크기를 권장합니다. 현재 값: %2$s.",
    "The PHP post_max_size is too low. A size of at least %1$s is recommended. Current value: %2$s." : "PHP의 post_max_filesize가 너무 작습니다. 최소한 %1$s 이상의 크기를 권장합니다. 현재 값: %2$s.",
    "PHP memory limit" : "PHP 메모리 제한",
    "PHP modules" : "PHP 모듈",
    "increases language translation performance and fixes sorting of non-ASCII characters" : ": 번역 성능을 개선과 비ASCII 문자의 바른 정렬을 위해 사용",
    "for Argon2 for password hashing" : ": Argon2의 암호 해싱을 위해 사용",
    "for picture rotation in server and metadata extraction in the Photos app" : ": 서버에서의 이미지 회전과 Photos 앱의 메타데이터 추출을 위해 사용",
    "This instance is missing some required PHP modules. It is required to install them: %s." : "이 인스턴스에 필수 PHP 모듈 중 일부가 존재하지 않습니다. 다음 모듈을 설치하십시오: %s",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them:\n%s" : "이 인스턴스에 권장 PHP 모듈 중 일부가 존재하지 않습니다. 성능 향상과 호환성을 위하여 다음 PHP 모듈을 설치하는 것이 좋습니다: %s",
    "PHP opcache" : "PHP opcache",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "PHP OPcache 모듈이 로드되지 않았습니다. 더 나은 성능을 위해 이를 PHP에 로드하는 것이 권장됩니다.",
    "OPcache is disabled. For better performance, it is recommended to apply \"opcache.enable=1\" to your PHP configuration." : "Opcache가 비활성화되었습니다. 성능 향상을 위해, PHP 설정에 \"opcache.enable=1\"을 적용하십시오.",
    "The shared memory based OPcache is disabled. For better performance, it is recommended to apply \"opcache.file_cache_only=0\" to your PHP configuration and use the file cache as second level cache only." : "공유 메모리 기반 OPcahce가 비활성화되었습니다. 성능 향상을 위해 PHP 설정에 \"opcache.file_cache_only=0\"을 적용하고, 파일 캐시를 2단계 캐시 전용으로 사용하십시오.",
    "OPcache is not working as it should, opcache_get_status() returns false, please check configuration." : "OPcache가 올바르게 작동하고 있지 않으며, opcache_get_status()가 false를 반환합니다. 설정을 확인하십시오.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply \"opcache.max_accelerated_files\" to your PHP configuration with a value higher than \"%s\"." : "OPcache 키의 최대 수에 거의 도달했습니다. 모든 스크립트가 캐시에 유지될 수 있도록, PHP 설정에서 \"opcache.max_accelerated_files\"를 \"%s\"보다 높은 값으로 적용하십시오.",
    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply \"opcache.memory_consumption\" to your PHP configuration with a value higher than \"%s\"." : "OPcache 버퍼가 거의 가득 찼습니다. 모든 스크립트가 캐시에 유지될 수 있도록, PHP 설정에서 \"opcache.memory_consumption\"을 \"%s\"보다 높은 값으로 적용하십시오.",
    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply \"opcache.interned_strings_buffer\" to your PHP configuration with a value higher than \"%s\"." : "OPcache interned strings 버퍼가 거의 가득 찼습니다. 반복되는 문자열이 효율적으로 캐싱되도록, PHP 설정에서 \"opcache.interned_strings_buffer\"를 \"%s\"보다 높은 값으로 적용하십시오.",
    "OPcache is configured to remove code comments. With OPcache enabled, \"opcache.save_comments=1\" must be set for Nextcloud to function." : "OPcache가 주석을 삭제하도록 설정되었습니다. OPcache 활성화 시, Nextcloud의 정상 동작을 위해  \"opcache.save_comments=1\"이 반드시 설정되어야 합니다.",
    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with \"opcache.restrict_api\" or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud가 OPcache API를 사용하도록 허용되지 않았습니다. OPcache 활성화 시 Nextcloud core 및 앱 업그레이드 시 오류를 방지하기 위해서는, 모든 Nextcloud 디렉토리를 \"opcache.restrict_api\"에 포함시키거나, 이 설정을 해제하여 OPcache API 제한을 비활성화하는 것이 좋습니다.",
    "The PHP OPcache module is not properly configured. %s." : "PHP OPcache 모듈이 올바르게 설정되지 않았습니다. %s",
    "Correctly configured" : "바르게 설정됨",
    "PHP version" : "PHP 버전",
    "You are currently running PHP %s." : "현재 PHP %s이(가) 동작 중입니다.",
    "PHP \"output_buffering\" option" : "PHP \"output_buffering\" 옵션",
    "PHP configuration option \"output_buffering\" must be disabled" : "PHP 설정 옵션 \"output_buffering\"은 반드시 비활성화해야 합니다.",
    "Push service" : "푸시 서비스",
    "Valid enterprise license" : "유효한 엔터프라이즈 라이센스",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {link}." : "이 빌드는 공식적으로 지원하지 않는 Nextcloud 커뮤니티 빌드입니다. 이 인스턴스의 크기를 고려하면, 성능과 신뢰성, 확장성 등을 보장할 수 없습니다. 무료 서비스의 과부하를 방지하기 위해 푸시 알림은 제한됩니다. Nextcloud Enterprise의 혜택에 대해서는 {link} (을)를 참조하십시오.",
    "Random generator" : "난수 생성기",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons." : "PHP가 적절한 난수 생성기를 찾을 수 없으며, 이는 보안에 상당히 좋지 않습니다.",
    "Secure" : "보안",
    "Configuration file access rights" : "설정 파일 접근 권한",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "읽기 전용 설정이 활성화되었습니다. 이 상태에서는 웹 인터페이스를 통하여 일부 설정을 변경할 수 없습니다. 또한 매 업데이트마다 파일을 쓸 수 있는 상태로 변경해야 합니다.",
    "Nextcloud configuration file is writable" : "Nextcloud 설정 파일이 쓰기가능한 상태입니다",
    "Database version" : "데이터베이스 버전",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend. This is particularly recommended when using the desktop client for file synchronisation. To migrate to another database use the command line tool: \"occ db:convert-type\"." : "SQLite가 현재 백엔드 데이터베이스로 사용중입니다. 더 큰 규모의 인스턴스에는 다른 데이터베이스 백엔드를 사용하는 것이 좋습니다. 이는 특히 데스크탑 클라이언트를 통한 파일 동기화를 사용할 때 권장됩니다. 다른 데이터베이스로 이전할 때에는 명령행 도구 \"occ db:convert-type\"을 사용하십시오.",
    "Unknown database platform" : "알 수 없는 데이터베이스 플랫폼",
    "64-bit" : "64비트",
    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit!" : "이 PHP가 32비트용인 것 같습니다. Nextcloud는 64비트 시스템에서 원활하게 동작합니다. OS와 PHP를 64비트로 업그레이드 하십시오.",
    "Temporary space available" : "임시 저장 공간을 사용할 수 있음",
    "Error while checking the temporary PHP path - it was not properly set to a directory. Returned value: %s" : "PHP 임시 디렉토리를 확인하는 중 오류 발생 - 올바른 디렉토리 설정이 아닙니다. 리턴 값: %s",
    "Error while checking the available disk space of temporary PHP path or no free disk space returned. Temporary path: %s" : "PHP 임시 디렉토리가 올바르게 설정되지 않았거나 해당 디렉토리에 여유 공간이 없습니다. 임시 디렉토리 경로: %s",
    "- %.1f GiB available in %s (PHP temporary directory)" : "- %s에서 %.1fGiB 사용할 수 있음 (PHP 임시 경로)",
    "- %.1f GiB available in %s (Nextcloud temporary directory)" : "- %s에서 %.1fGiB 사용할 수 있음 (Nextcloud 임시 경로)",
    "Temporary directory is correctly configured:\n%s" : "임시 디렉토리가 바르게 설정됨:\n%s",
    "This instance uses an S3 based object store as primary storage, and has enough space in the temporary directory.\n%s" : "이 인스턴스는 S3 기반 객체 스토리지를 주 저장소로 사용하고 있으며, 임시 디렉토리의 여유 공간이 충분합니다.\n%s",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GiB of free space available in the temp directory of PHP. To improve this please change the temporary directory in the php.ini or make more space available in that path. \nChecking the available space in the temporary path resulted in %.1f GiB instead of the recommended 50 GiB. Path: %s" : "이 인스턴스는 S3 기반 객체 스토리지를 주 저장소로 사용하고 있습니다. 업로드된 파일은 임시로 서버에 저장되므로, 임시 디렉토리에 50GiB 이상의 여유 공간이 있는 것이 좋습니다. php.ini 파일에서 임시 디렉토리를 변경하거나, 임시 디렉토리에 더 많은 여유 공간을 확보하십시오.\n임시 디렉토리의 여유공간이 %.1f GiB로 확인됩니다. 권장값은 50GiB입니다. 경로: %s",
    "Database transaction isolation level" : "데이터베이스 트랜잭션 격리 수준",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "데이터베이스가 \"READ COMMITTED\" 트랜잭션 격리 수준에서 실행되고 있지 않습니다. 여러 작업이 동시에 실행될 때 문제가 발생할 수 있습니다.",
    "Was not able to get transaction isolation level: %s" : "트랜잭션 격리 수준 %s을(를) 취하지 못했습니다",
    "Profile information" : "프로필 정보",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "프로필 사진, 전체 이름, 이메일, 전화번호, 주소, 웹사이트, 트위터, 조직, 직책, 표제, 소개문구 및 프로필 활성화 여부",
    "Nextcloud settings" : "Nextcloud 환경설정",
    "AI tasks can be implemented by different apps. Here you can set which app should be used for which task." : "AI 작업을 다양한 앱들을 통해 구현할 수 있습니다. 이곳에서 어떤 작업에 어떤 앱을 사용할지 설정할 수 있습니다.",
    "Enable" : "사용함",
    "None of your currently installed apps provide Task processing functionality" : "설치된 앱들 중 작업 처리 기능을 제공하는 것이 없습니다.",
    "Machine translation" : "기계 번역",
    "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "기계 번역은 다양한 앱들을 통해 구현할 수 있습니다. 이곳에서 현재 설치한 기계 번역 앱들의 우선 순위를 결정할 수 있습니다.",
    "Image generation" : "이미지 생성",
    "Image generation can be implemented by different apps. Here you can set which app should be used." : "이미지 생성 기능을 채용한 앱이 이곳에 표시됩니다. 이미지 생성 기능을 사용할 앱을 선택하십시오. ",
    "None of your currently installed apps provide image generation functionality" : "현재 설치된 앱 중 이미지 생성 기능을 제공하는 것이 없습니다",
    "Text processing" : "문장 처리",
    "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "문장처리 기술을 채용한 앱이 이곳에 표시됩니다. 문장처리 기술을 사용할 앱과 해당 기술이 사용될 작업을 설정하십시오.",
    "Task:" : "작업:",
    "None of your currently installed apps provide text processing functionality using the Text Processing API." : "설치된 앱들 중 텍스트 처리 API를 사용하여 텍스트 처리 기능을 제공하는 것이 없습니다.",
    "Here you can decide which group can access certain sections of the administration settings." : "이곳에서 각 설정 메뉴별로 해당 메뉴에 접근 가능한 그룹을 지정할 수 있습니다.",
    "Unable to modify setting" : "설정을 수정할 수 없습니다.",
    "None" : "없음",
    "Changed disclaimer text" : "고지 사항 문구를 변경함",
    "Deleted disclaimer text" : "고지 사항 문구를 삭제함",
    "Could not set disclaimer text" : "고지 사항 문구를 설정할 수 없음",
    "Allow apps to use the Share API" : "앱에서 공유 API를 사용할 수 있도록 허용",
    "Allow resharing" : "재공유 허용",
    "Allow sharing with groups" : "그룹과 공유 허용",
    "Restrict users to only share with users in their groups" : "그룹 내 사용자끼리만 공유할 수 있도록 허용",
    "Ignore the following groups when checking group membership" : "그룹 멤버쉽 확인 시 다음 그룹을 무시",
    "Allow users to share via link and emails" : "사용자가 링크와 이메일을 통해 공유하는 것 허용",
    "Allow public uploads" : "공개 업로드 허용",
    "Always ask for a password" : "항상 암호 묻기",
    "Enforce password protection" : "암호 보호 강제",
    "Exclude groups from password requirements" : "특정 그룹을 암호 요구조건에서 예외로 설정",
    "Exclude groups from creating link shares" : "특정 그룹에 대해 링크 공유 생성을 금지하도록 설정",
    "Limit sharing based on groups" : "그룹별로 공유 제한하기",
    "Allow sharing for everyone (default)" : "그룹별 공유 기능 제한 없음 (기본값)",
    "Exclude some groups from sharing" : "공유 기능을 제한할 그룹 지정",
    "Limit sharing to some groups" : "공유 기능을 허용할 그룹 지정",
    "Groups allowed to share" : "공유가 허용된 그룹",
    "Groups excluded from sharing" : "공유에서 제외된 그룹",
    "Not allowed groups will still be able to receive shares, but not to initiate them." : "공유가 제한된 그룹은 다른 사람의 데이터를 공유 받을 수는 있지만, 다른 사람에게 자신의 데이터를 공유할 수는 없습니다.",
    "Set default expiration date for internal shares" : "내부 공유에 기본 만료 기간을 설정",
    "Enforce expiration date" : "만료 날짜 강제",
    "Default expiration time of new shares in days" : "공유에 대한 기본 유효기간 (일 단위)",
    "Expire shares after x days" : "x일 후 공유가 만료됨",
    "Set default expiration date for shares to other servers" : "다른 서버와의 공유에 대한 기본 만료 날짜 설정",
    "Enforce expiration date for remote shares" : "원격 공유에 대해 유효기간 설정을 강제",
    "Default expiration time of remote shares in days" : "원격 공유에 대한 기본 유효기간 (일 단위)",
    "Expire remote shares after x days" : "x일 후 원격 공유가 만료됨",
    "Set default expiration date for shares via link or mail" : "링크 및 메일 공유에 대한 기본 만료 날짜 설정",
    "Default expiration time of shares in days" : "공유에 대한 기본 유효기간 (일 단위)",
    "Privacy settings for sharing" : "공유에 대한 개인정보 보호 설정",
    "Allow account name autocompletion in share dialog and allow access to the system address book" : "공유 대화 상자에서 계정 이름 자동 완성을 허용하고 시스템 주소록에 접근 허가하기",
    "Restrict account name autocompletion and system address book access to users within the same groups" : "계정 이름 자동 완성과 시스템 주소록 접근 권한을 같은 그룹의 사용자에게로 제한",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "공개 링크 업로드 페이지에 고지 사항 문구를 표시 (파일 목록이 숨겨져 있는 경우에만 표시)",
    "Disclaimer text" : "고지 사항 문구",
    "This text will be shown on the public link upload page when the file list is hidden." : "파일 목록이 숨겨져 있으면 이 텍스트는 공개 링크 업로드 페이지에 표시됩니다.",
    "Default share permissions" : "기본 공유 권한",
    "Two-Factor Authentication" : "2단계 인증",
    "Two-factor authentication can be enforced for all accounts and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "2단계 인증을 모든 계정 또는 특정 그룹에 강제할 수 있습니다. 만약 대상 계정이 2단계 인증 공급자를 설정하지 않았다면, 해당 계정은 시스템에 접근할 수 없게 될 것입니다.",
    "Enforce two-factor authentication" : "2단계 인증 강제하기",
    "Limit to groups" : "그룹으로 제한",
    "Enforcement of two-factor authentication can be set for certain groups only." : "2단계 인증 강제는 특정 그룹에게만 적용됩니다.",
    "Two-factor authentication is enforced for all members of the following groups." : "2단계 인증이 모든 멤버에게 강제된 그룹은 다음과 같습니다.",
    "Enforced groups" : "강제된 그룹",
    "Two-factor authentication is not enforced for members of the following groups." : "2단계 인증이 강제되지 않은 그룹은 다음과 같습니다.",
    "Excluded groups" : "제외된 그룹",
    "When groups are selected/excluded, they use the following logic to determine if an account has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If an account is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "그룹을 선택하거나 제외하면 이들의 계정에 2FA를 강제할지 다음 로직을 통해 결정합니다: 아무 그룹도 선택하지 않으면, 제외된 그룹의 사용자들을 제외한 모두에게 2FA가 활성화됩니다. 그룹을 선택했다면, 그 그룹(들)의 모든 멤버들에게 2FA가 활성화됩니다. 하나의 계정이 선택한 그룹과 제외한 그룹에 동시에 있다면, 선택한 그룹이 우선순위를 가져 2FA가 강제됩니다.",
    "Save changes" : "변경 사항 저장",
    "Default" : "디폴트",
    "Registered Deploy daemons list" : "등록된 배포 데몬 목록",
    "No Deploy daemons configured" : "배포 데몬이 구성되지 않았습니다.",
    "Register a custom one or setup from available templates" : "사용자 정의 항목을 등록하거나 사용 가능한 템플릿에서 설정",
    "Show details for {appName} app" : "{appName} 앱에 대한 상세 정보 보기",
    "Update to {update}" : "{update}(으)로 업데이트",
    "Remove" : "삭제",
    "Featured" : "추천",
    "This app is supported via your current Nextcloud subscription." : "이 앱은 당신의 현재 Nextcloud 구독을 통해 지원됩니다.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "추천 앱은 커뮤니티에서 개발했습니다. 이들은 생산성 업무에 있어 중심적인 기능을 담당하며 즉각 사용될 수 있습니다.",
    "Community rating: {score}/5" : "커뮤니티 평가: {score}/5",
    "Disable all" : "전체 비활성화",
    "Download and enable all" : "모두 다운로드 및 사용",
    "All apps are up-to-date." : "모든 앱이 최신 버전입니다.",
    "Icon" : "아이콘",
    "Name" : "이름",
    "Version" : "버전",
    "Level" : "단계",
    "Actions" : "동작",
    "Results from other categories" : "다른 카테고리로부터의 결과",
    "No apps found for your version" : "설치된 버전에 대한 앱 없음",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n개의 앱을 업데이트 할 수 있습니다."],
    "_Update_::_Update all_" : ["모두 업데이트"],
    "Failed to create group" : "그룹을 만들 수 없음",
    "Groups" : "그룹",
    "Creating group…" : "그룹 생성 ...",
    "Create group" : "그룹 생성",
    "Group name" : "그룹 이름",
    "Please enter a valid group name" : "올바른 그룹 이름을 입력하세요",
    "Search groups…" : "그룹 검색",
    "Loading groups…" : "그룹 불러오는 중...",
    "Could not load app discover section" : "앱 검색 섹션을 불러올 수 없음",
    "Could not render element" : "요소를 렌더할 수 없음",
    "Nothing to show" : "표시할 항목 없음",
    "Could not load section content from app store." : "앱 스토어에서 섹션 내용을 가져올 수 없음",
    "Loading" : "불러오는 중",
    "Fetching the latest news…" : "최신 소식 가져오는 중...",
    "Carousel" : "캐러셀",
    "Previous slide" : "이전 슬라이드",
    "Next slide" : "다음 슬라이드",
    "Choose slide to display" : "표시할 슬라이드 선택",
    "{index} of {total}" : "{total}개 중 {index}",
    "Daemon" : "데몬",
    "Deploy Daemon" : "배포 데몬",
    "Type" : "종류",
    "Display Name" : "표시 이름",
    "GPUs support" : "GPU 지원<br>",
    "Compute device" : "컴퓨팅 장치",
    "Learn more" : "자세히 알아보기",
    "Environment variables" : "환경 변수",
    "Read-only" : "읽기 전용",
    "Confirm" : "확인",
    "Cancel" : "취소",
    "Description" : "설명",
    "View in store" : "스토어에서 보기",
    "Visit website" : "웹 사이트 방문",
    "Usage documentation" : "사용법 문서",
    "Admin documentation" : "관리 문서",
    "Developer documentation" : "개발자 문서",
    "Details" : "세부사항",
    "All" : "모두",
    "Limit app usage to groups" : "앱 사용을 그룹으로 제한합니다.",
    "No results" : "검색 결과 없음",
    "Update to {version}" : "{version}(으)로 업데이트",
    "Default Deploy daemon is not accessible" : "기본 배포 데몬에 액세스할 수 없음",
    "Delete data on remove" : "제거 시 데이터 삭제",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "다음 의존성을 만족할 수 없기 때문에 이 앱을 설치할 수 없습니다:",
    "Latest updated" : "최신 업데이트됨",
    "Author" : "저자",
    "Categories" : "분류",
    "Resources" : "자원",
    "Documentation" : "문서",
    "Interact" : "상호작용",
    "Report a bug" : "버그 보고",
    "Request feature" : "기능 요청",
    "Ask questions or discuss" : "질문 및 토론",
    "Rate the app" : "앱 평가하기",
    "Rate" : "평가",
    "Changelog" : "변경 기록",
    "Google Chrome for Android" : "Android용 Google 크롬",
    "{productName} iOS app" : "{productName} iOS 앱",
    "{productName} Android app" : "{productName} Android 앱",
    "{productName} Talk for iOS" : "{productName} iOS용 Talk",
    "{productName} Talk for Android" : "{productName} Android용 Talk",
    "Sync client" : "클라이언드 동기화",
    "This session" : "이 세션",
    "Device name" : "기기 이름",
    "Cancel renaming" : "이름 변경 취소",
    "Save new name" : "새 이름 저장",
    "Marked for remote wipe" : "원격 제거를 위해 지정됨",
    "Device settings" : "디바이스 설정",
    "Allow filesystem access" : "파일시스템 접근 허용",
    "Rename" : "이름 바꾸기",
    "Revoke" : "취소",
    "Wipe device" : "디바이스 지우기",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "기기 제거가 아직 시작되지 않았다면, 이 토큰을 취소하여 기기의 제거를 방지할 수 있습니다.",
    "Device" : "장치",
    "Last activity" : "최근 활동",
    "Devices & sessions" : "디바이스 & 세션",
    "Web, desktop and mobile clients currently logged in to your account." : "사용자 계정으로 로그인된 웹, 데스크톱, 모바일 클라이언트 목록입니다.",
    "Error while creating device token" : "장치 토큰을 만드는 중 오류가 발생했습니다",
    "App name" : "앱 이름",
    "Create new app password" : "새로운 앱 암호 만들기",
    "App password copied!" : "앱 암호가 복사되었습니다!",
    "Copy app password" : "앱 암호 복사",
    "Login name copied!" : "로그인 이름이 복사되었습니다!",
    "Copy login name" : "로그인 이름 복사",
    "Could not copy app password. Please copy it manually." : "앱 암호를 복사할 수 없습니다. 수동으로 복사해 주세요.",
    "Could not copy login name. Please copy it manually." : "로그인 이름을 자동으로 복사할 수 없습니다. 수동으로 복사하십시오.",
    "New app password" : "새 앱 암호",
    "Use the credentials below to configure your app or device. For security reasons this password will only be shown once." : "다음의 인증 정보를 사용하여 앱과 장치를 설정하십시오. 보안을 위해 암호는 한 번만 표시됩니다.",
    "Login" : "로그인",
    "Password" : "암호",
    "Show QR code for mobile apps" : "모바일 앱을 위한 QR코드를 보여주세요.",
    "Use system cron service to call the cron.php file every 5 minutes." : "시스템 cron 서비스를 통해 5분마다 cron.php 파일을 실행합니다.",
    "The cron.php needs to be executed by the system account \"{user}\"." : "시스템 계정 \"{user}\"(으)로 cron.php를 실행해야 합니다.",
    "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "PHP POSIX 확장이 필요합니다. 더 자세한 정보는 {linkstart}PHP 문서{linkend}를 참조하십시오.",
    "Unable to update background job mode" : "백그라운드 작업 모드를 업데이트 할 수 없음",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "서버가 적절하게 동작하기 위해 백그라운드 작업을 올바르게 설정하는 것이 중요합니다. Cron으로 설정하는 것을 권장합니다. 더 많은 정보는 문서를 참조하십시오.",
    "Last job execution ran {time}. Something seems wrong." : "마지막 작업이 {time}에 실행되었습니다. 무언가 잘못된 것 같습니다.",
    "Last job ran {relativeTime}." : "마지막 작업이 {relativeTime}에 실행되었음",
    "Background job did not run yet!" : "백그라운드 작업이 아직 실행되지 않았습니다!",
    "AJAX" : "AJAX",
    "Execute one task with each page loaded. Use case: Single account instance." : "페이지를 로드할 때마다 작업을 실행합니다. 계정이 하나인 인스턴스에 적합합니다.",
    "Webcron" : "Webcron",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 accounts depending on the usage)." : "cron.php를 webcron 서비스에 등록하여 매 5분마다 HTTP 상에서 실행합니다. 계정이 다섯 개 이하인 소규모 인스턴스에 적합합니다.",
    "Cron (Recommended)" : "Cron (권장됨)",
    "Unable to update profile default setting" : "프로필 기본 설정을 업데이트 할 수 없음",
    "Profile" : "프로필",
    "Enable or disable profile by default for new accounts." : "신규 계정에 대한 프로필 기본 사용 여부를 설정하십시오.",
    "Password confirmation is required" : "암호 확인이 필요합니다",
    "Failed to save setting" : "설정 저장 실패",
    "Unable to update server side encryption config" : "서버 측 암호화 설정을 갱신할 수 없음",
    "Server-side encryption" : "서버 측 암호화",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "서버 측 암호화를 사용하면 이 서버에 업로드되는 파일을 암호화할 수 있습니다. 성능 감소 등 제약 사항이 있으므로 필요한 경우에만 사용하십시오.",
    "Enable server-side encryption" : "서버 측 암호화 사용",
    "No encryption module loaded, please enable an encryption module in the app menu." : "암호화 모듈을 불러오지 않았습니다. 앱 메뉴에서 암호화 모듈을 활성화하십시오.",
    "Select default encryption module:" : "기본 암호화 모듈 선택:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "과거에 사용하였던(ownCloud <= 8.0) 암호화된 데이터에서 키를 이전해야 합니다. \"기본 암호화 모듈\"을 활성화한 다음 {command}(을)를 실행하십시오",
    "Enable encryption" : "암호화 사용",
    "Please read carefully before activating server-side encryption:" : "서버 측 암호화를 활성화하기 전에 읽어 보세요:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "암호화를 사용하면, 사용하기 시작한 시간 이후에 서버에 업로드된 모든 파일이 암호화됩니다. 나중에 암호화를 사용하지 않으려면 사용하고 있는 암호화 모듈에서 비활성화를 지원해야 하고 모든 사전 조건(예: 복구 키 설정)을 만족해야 합니다.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "암호화만으로 시스템의 보안을 보장할 수 없습니다. 암호화 응용 프로그램 작동 방식 및 지원되는 사용 사례에 대한 자세한 내용은 설명서를 참조하십시오.",
    "Be aware that encryption always increases the file size." : "암호화된 파일의 크기는 항상 커집니다.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "데이터를 주기적으로 백업하는 것을 추천하며, 암호화를 사용하고 있다면 데이터와 더불어 암호화 키도 백업하십시오.",
    "This is the final warning: Do you really want to enable encryption?" : "마지막 경고입니다. 암호화를 활성화하시겠습니까?",
    "Please confirm the group removal" : "그룹 지우기를 확인해 주십시오",
    "Submit" : "제출",
    "Rename group" : "그룹 이름 바꾸기",
    "Current password" : "현재 암호",
    "New password" : "새 암호",
    "Change password" : "암호 변경",
    "Choose your profile picture" : "프로필 사진을 선택하십시오",
    "Please select a valid png or jpg file" : "올바른 PNG 또는 JPG 파일을 선택하십시오",
    "Error setting profile picture" : "프로필 사진 설정 중 오류 발생",
    "Error cropping profile picture" : "프로필 사진을 자르는 중 오류 발생",
    "Error saving profile picture" : "프로필 사진 저장 중 오류 발생",
    "Error removing profile picture" : "프로필 사진 삭제 중 오류 발생",
    "Your profile picture" : "내 프로필 사진",
    "Upload profile picture" : "프로필 사진 업로드",
    "Choose profile picture from Files" : "내 파일에서 프로필 사진 선택",
    "Remove profile picture" : "프로필 사진 삭제",
    "The file must be a PNG or JPG" : "파일은 PNG 또는 JPG여야 합니다.",
    "Picture provided by original account" : "원래 계정에서 제공하는 사진",
    "Set as profile picture" : "프로필 사진으로 설정",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "프로필사진이 모든 곳에 갱신될 때까지 최대 24시간이 걸릴 수 있습니다.",
    "Unable to update date of birth" : "생일 변경 실패",
    "Enter your date of birth" : "생일을 입력하세요",
    "You are a member of the following groups:" : "당신은 다음 그룹의 멤버입니다:",
    "Your full name" : "내 전체 이름",
    "Unable to update primary email address" : "주 이메일 주소를 갱신할 수 없음",
    "Unable to delete additional email address" : "추가 이메일 주소를 삭제할 수 없음",
    "No email address set" : "이메일 주소가 설정되지 않음",
    "Email options" : "이메일 옵션",
    "Remove primary email" : "주 이메일 삭제",
    "Delete email" : "이메일 삭제",
    "This address is not confirmed" : "이 주소는 확인되지 않음",
    "Unset as primary email" : "주 이메일 지정 해제",
    "Set as primary email" : "주 이메일로 지정",
    "Additional email address {index}" : "추가 이메일 주소 {index}",
    "Unable to delete primary email address" : "주 이메일 주소를 삭제할 수 없음",
    "Unable to add additional email address" : "추가 이메일 주소를 추가할 수 없음",
    "Unable to update additional email address" : "추가 이메일 주소를 갱신할 수 없음",
    "Primary email for password reset and notifications" : "암호 초기화 및 알림 수신용 주 이메일 주소",
    "Your handle" : "내 아이디",
    "Derived from your locale ({weekDayName})" : "지역의 규정을 바탕으로 함({weekDayName})",
    "Your headline" : "내 표제",
    "No language set" : "언어가 설정되지 않음",
    "Unable to update language" : "언어를 갱신할 수 없음",
    "Languages" : "언어",
    "Help translate" : "번역 돕기",
    "No locale set" : "지역이 설정되지 않음",
    "Unable to update locale" : "지역을 갱신할 수 없음",
    "Locales" : "지역",
    "Week starts on {firstDayOfWeek}" : "일주일이 {firstDayOfWeek}에 시작함",
    "Your city" : "내 도시",
    "Your organisation" : "내 조직",
    "Your phone number" : "내 휴대폰 번호",
    "Edit your Profile visibility" : "프로필 표시 여부 편집",
    "Unable to update profile enabled state" : "프로필 활성화 여부를 갱신할 수 없음",
    "Enable profile" : "프로필 활성화",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "표시 여부나 표시 범위 설정은 더 좁은 쪽이 우선 적용됩니다. 예를 들어, 표시 여부는 \"전체 공개\", 표시 범위는 \"개인\"으로 설정되어 있다면, 해당 항목은 \"개인\"에게만 보여집니다.",
    "Unable to update visibility of {displayId}" : "{displayId}의 표시 여부를 갱신할 수 없음",
    "Your role" : "내 직책",
    "Timezone" : "시간대",
    "Your X (formerly Twitter) handle" : "내 X (구 Twitter) 아이디",
    "Your website" : "내 웹 사이트",
    "Invalid value" : "잘못된 값",
    "Unable to update {property}" : "{property}을(를) 갱신할 수 없음",
    "No {property} set" : "{property}이(가) 설정되지 않음",
    "Add additional email" : "추가 이메일 추가",
    "Add" : "추가",
    "Create" : "생성",
    "Change" : "변경",
    "Delete" : "삭제",
    "Reshare" : "재공유",
    "School" : "학교",
    "Default language" : "기본 언어",
    "Common languages" : "공통 언어",
    "Other languages" : "다른 언어",
    "Password change is disabled because the master key is disabled" : "마스터 키가 비활성화 되어 암호 변경이 비활성화 됨",
    "No accounts" : "계정 없음",
    "List of accounts. This list is not fully rendered for performance reasons. The accounts will be rendered as you navigate through the list." : "계정 목록입니다. 성능 저하를 막기 위해 이 목록을 완전히 처리하지 않았습니다. 계속 탐색하면 남은 목록이 자동으로 처리됩니다.",
    "Manager" : "담당 관리자",
    "New account" : "새로운 계정",
    "Display name" : "표시 이름",
    "Either password or email is required" : "암호 또는 이메일이 필요합니다",
    "Password (required)" : "암호 (필수)",
    "Email (required)" : "이메일 (필수)",
    "Email" : "이메일",
    "Quota" : "할당량",
    "Language" : "언어",
    "Set default language" : "기본 언어 지정",
    "Total rows summary" : "총 행 요약",
    "Scroll to load more rows" : "스크롤 하여 더 불러오기",
    "Avatar" : "아바타",
    "Account name" : "계정 아이디",
    "Group admin for" : "다음 그룹의 관리자:",
    "Storage location" : "저장소 위치",
    "Last login" : "마지막 로그인",
    "Account actions" : "계정 동작",
    "{size} used" : "{size} 사용됨",
    "Delete account" : "계정 삭제",
    "Disable account" : "계정 비활성화",
    "Enable account" : "계정 활성화",
    "Resend welcome email" : "환영 메일 다시 보내기",
    "Remote wipe of devices" : "기기 원격 제거",
    "Wipe {userid}'s devices" : "{userid}의 기기 제거",
    "Wiped {userid}'s devices" : "{userid}의 기기를 제거함",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "모든 개인 파일, 앱, 데이터 등을 포함한 {userid} 계정을 완전히 삭제하기",
    "Account deletion" : "계정 삭제",
    "Delete {userid}'s account" : "{userid}의 계정 삭제",
    "Display name was successfully changed" : "표시 이름이 성공적으로 변경됨",
    "Password was successfully changed" : "암호를 성공적으로 변경함",
    "Email was successfully changed" : "이메일을 성공적으로 변경함",
    "Welcome mail sent!" : "환영 메일을 보냈습니다!",
    "Change display name" : "표시 이름 변경",
    "Set new password" : "새 암호 설정",
    "You do not have permissions to see the details of this account" : "이 계정의 상세정보를 볼 권한이 없습니다.",
    "Set new email address" : "새 이메일 주소 설정",
    "Add account to group" : "계정을 그룹에 추가",
    "Set account as admin for" : "계정을 다음에 대한 관리자로 설정: ",
    "Select account quota" : "계정 할당량 설정",
    "Set the language" : "언어 설정",
    "Toggle account actions menu" : "계정 동작 메뉴 켜고 끄기",
    "Done" : "완료",
    "Edit" : "편집",
    "Account management settings" : "계정 관리 설정",
    "Visibility" : "표시 여부",
    "Show language" : "언어 보이기",
    "Show account backend" : "계정 백엔드 보이기",
    "Show storage path" : "스토리지 경로 보이기",
    "Show last login" : "마지막 로그인 보이기",
    "Sorting" : "정렬",
    "Send email" : "이메일 보내기",
    "Send welcome email to new accounts" : "새 계정에 환영 이메일 보내기",
    "Defaults" : "기본값",
    "Default quota" : "기본 할당량",
    "Select default quota" : "기본 할당량 설정",
    "Server error while trying to complete WebAuthn device registration" : "WebAuthn 기기 등록을 마치는 중 오류 발생",
    "Passwordless authentication requires a secure connection." : "무암호 인증을 위해 보안 연결이 필요합니다.",
    "Add WebAuthn device" : "WebAuthn 기기 추가",
    "Please authorize your WebAuthn device." : "내 WebAuthn 기기를 인증하십시오.",
    "Unnamed device" : "이름 없는 장치",
    "Passwordless Authentication" : "무암호 인증",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "FIDO2 기준을 준수하여 계정에 무암호 인증을 설정하세요.",
    "No devices configured." : "설정된 기기가 없습니다.",
    "The following devices are configured for your account:" : "다음의 기기가 계정에 설정되었습니다:",
    "Your browser does not support WebAuthn." : "WebAuthn이 현재 브라우저를 지원하지 않습니다.",
    "Security & setup warnings" : "보안 및 설치 경고",
    "Try again" : "다시 시도",
    "All checks passed." : "모든 검사를 통과했습니다.",
    "There are some errors regarding your setup." : "설정을 살펴본 결과 몇 가지 오류가 있습니다.",
    "There are some warnings regarding your setup." : "설정을 살펴본 결과 몇 가지 경고할 것이 있습니다.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "관리자로 공유 행동을 미세 조정할 수 있습니다. 더 많은 정보를 보려면 문서를 참조하십시오.",
    "You need to enable the File sharing App." : "파일 공유 앱을 활성화해야 합니다.",
    "Developer documentation ↗" : "개발자 문서 ↗",
    "Apply" : "적용",
    "Admins" : "관리자",
    "Account group: {group}" : "계정 그룹: {group}",
    "Account management" : "계정 관리",
    "Sending…" : "보내는 중…",
    "Email sent" : "이메일 보냄",
    "Location" : "위치",
    "Profile picture" : "프로필 사진",
    "About" : "정보",
    "Date of birth" : "생일",
    "Full name" : "전체 이름",
    "Additional email" : "추가 이메일",
    "Fediverse (e.g. Mastodon)" : "Fediverse (예: Mastodon)",
    "Headline" : "표제",
    "Organisation" : "조직",
    "Phone number" : "휴대폰 번호",
    "Role" : "직책",
    "X (formerly Twitter)" : "X (구 Twitter)",
    "Website" : "웹사이트",
    "Profile visibility" : "프로필 표시 여부",
    "Locale" : "지역",
    "First day of week" : "주 시작 요일",
    "Private" : "개인",
    "Only visible to people matched via phone number integration through Talk on mobile" : "전화번호 통합으로 연결된 사용자에게만 보임",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "이 설정은 파일 공유, 달력 초대 등 핵심 기능에 필요하므로 비울 수 없습니다",
    "Local" : "로컬",
    "Only visible to people on this instance and guests" : "이 인스턴스의 사용자와 손님만 볼 수 있음",
    "Federated" : "연합",
    "Only synchronize to trusted servers" : "신뢰할 수 있는 서버만 동기화할 수 있습니다.",
    "Not available as federation has been disabled for your account, contact your system administration if you have any questions" : "이 계정에 대한 연합이 비활성화되어 현재 사용할 수 없는 상태입니다. 시스템 관리자에게 문의하십시오.",
    "Published" : "발행됨",
    "Synchronize to trusted servers and the global and public address book" : "신뢰할 수 있는 서버와 전역 및 개인 연락처에 동기화",
    "Your apps" : "내 앱",
    "Active apps" : "활성화된 앱",
    "Disabled apps" : "비활성화된 앱",
    "Updates" : "업데이트",
    "App bundles" : "앱 번들",
    "Featured apps" : "추천 앱 - ",
    "Supported apps" : "지원하는 앱",
    "Show to everyone" : "전체 공개",
    "Show to logged in accounts only" : "로그인된 계정에 공개",
    "Hide" : "비공개",
    "Deploy and Enable" : "배포 및 활성화",
    "Download and enable" : "다운로드 및 사용",
    "Disable" : "사용 안함",
    "Allow untested app" : "확인되지 않은 앱 허용",
    "The app will be downloaded from the App Store" : "이 앱이 앱 스토어에서 다운로드됩니다.",
    "Unknown" : "알 수 없음",
    "Never" : "하지 않음",
    "Could not register device: Network error" : "기기를 등록할 수 없음: 네트워크 오류",
    "Could not register device: Probably already registered" : "기기를 등록할 수 없음: 이미 등록된 기기인 것 같습니다",
    "Could not register device" : "기기를 등록할 수 없음",
    "An error occurred during the request. Unable to proceed." : "요청을 보내는 도중 오류가 발생하였습니다. 더 이상 진행할 수 없습니다.",
    "The app has been enabled but needs to be updated." : "앱이 활성화 되었으나 업데이트가 필요합니다.",
    "Error: This app cannot be enabled because it makes the server unstable" : "오류: 이 앱은 서버를 불안정하게 만들 수 있어서 활성화할 수 없습니다.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "앱이 활성화되었지만, 앱을 업데이트해야 합니다. 5초 후 앱 업데이트 페이지로 넘어갑니다.",
    "Do you really want to wipe your data from this device?" : "정말 이 기기로 부터 데이터를  지우시겠습니까?",
    "Confirm wipe" : "삭제 완료",
    "Could not delete the app token" : "앱 토큰을 삭제할 수 없음",
    "Error while wiping the device with the token" : "토큰으로 기기를 제거하는 도중 오류 발생",
    "Error while updating device token name" : "기기 토큰 이름을 갱신하는 중 오류 발생",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "이 네트워크에 너무 요청이 많습니다. 나중에 다시 시도하십시오. 이것이 오류일 경우 관리자에게 문의하십시오.",
    "Error" : "오류",
    "Account documentation" : "계정 문서",
    "Administration documentation" : "관리 문서",
    "Forum" : "포럼",
    "General documentation" : "일반 문서",
    "Legal notice" : "법적 고지",
    "Privacy policy" : "개인 정보 취급 방침",
    "None/STARTTLS" : "없음/STARTTLS",
    "SSL" : "SSL",
    "Open documentation" : "문서 열기",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "암호 초기화 및 알림 이메일을 보내려면 이메일 서버를 설정해야 합니다.",
    "Send mode" : "보내기 모드",
    "Encryption" : "암호화",
    "Sendmail mode" : "Sendmail 모드",
    "From address" : "보낸 사람 주소",
    "Server address" : "서버 주소",
    "Port" : "포트",
    "Authentication" : "인증",
    "Authentication required" : "인증 필요함",
    "Credentials" : "인증 정보",
    "SMTP Login" : "SMTP 로그인",
    "SMTP Password" : "SMTP 암호",
    "Save" : "저장",
    "Test and verify email settings" : "이메일 설정 테스트 및 검증",
    "Reasons to use Nextcloud in your organization" : "당신의 조직에서 Nextcloud를 사용해야 할 이유",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "{communityopen}Nextcloud 커뮤니티{linkclose}에서 개발, {githubopen}소스 코드{linkclose}는 {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose} 라이선스를 따릅니다.",
    "Like our Facebook page" : "Facebook 페이지에서 좋아요 누르기",
    "Follow us on Mastodon" : "Mastodon에서 팔로우하기",
    "Check out our blog" : "블로그 확인하기",
    "Subscribe to our newsletter" : "뉴스레터 구독하기",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "이 Nextcloud 커뮤니티 릴리즈는 지원되지 않으며 즉각적인 알림을 사용할 수 없습니다.",
    "Use a second factor besides your password to increase security for your account." : "사용자의 계정을 더욱 안전하게 보호하기 위해 암호와 함께 2단계 인증을 사용하세요.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Nextcloud에 연결하기 위해 서드파티 애플리케이션을 사용할 경우 2차 인증을 활성화하기 앞서 각 애플리케이션에 대한 앱 암호를 생성, 설정하십시오.",
    "Group list is empty" : "그룹 목록이 비었음",
    "Unable to retrieve the group list" : "그룹 목록을 받아올 수 없음",
    "Logged in account must be a subadmin" : "로그인한 계정은 부관리자여야 합니다.",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "이 앱은 Nextcloud 최소 버전을 지정하지 않았습니다. 차후 버전에서는 오류로 처리됩니다.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "이 앱은 Nextcloud 최대 버전을 지정하지 않았습니다. 차후 버전에서는 오류로 처리됩니다.",
    "Loading accounts …" : "계정 불러오는 중 ...",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "기기를 분실했거나 조직에서 이탈할 경우, 이를 통해 모든 기기에 있는 {userid} 관련 Nextcloud 데이터를 원격으로 삭제할 수 있습니다. 해당 기기들이 인터넷에 연결된 경우에 한하여 작동합니다.",
    "Loading account …" : "계정 불러오는 중 ...",
    "Adding your device …" : "장치 추가 중 …",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "이 앱은 현재 Nextcloud 버젼과 호환되지 않습니다.  이 앱을 설치하면, 제대로 작동하지 않을 수 있습니다.",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "정확한 설정은 인스턴스의 보안과 성능에 중요합니다. 아래의 자동 진단 결과를 참조하여 최적의 설정으로 조정하십시오. 더 자세한 정보를 위해서 링크된 문서를 참고하세요.",
    "Checking for system and security issues." : "시스템과 보안에 대한 문제를 확인하는 중",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">설치 가이드 ↗</a>를 다시 한 번 확인한 다음 <a href=\"%2$s\">로그</a>의 경고나 오류를 확인하세요.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">우리의 보안 검사 ↗</a>에서 이 Nextcloud의 보안을 점검하세요."
},
"nplurals=1; plural=0;");
